<div>
    @push('styles')
    <style>
        /* Asegura que el encabezado de la tabla se mantenga fijo */
        .sticky-top {
            position: sticky;
            top: 0;
            z-index: 2;
        }

        /* Evita el salto de línea en las celdas */
        .table td, .table th {
            white-space: nowrap;
            vertical-align: middle;
        }

        /* Ajusta la tabla para que no tenga scroll vertical */
        .table-responsive {
            overflow-x: auto; /* Permite scroll horizontal si es necesario */
            max-height: none;  /* Quita el scroll vertical */
        }
    </style>
    @endpush

    <div>

        <div class="d-flex justify-content-between mb-3">
            <h3>Gestión de Predios</h3>
            <button class="btn btn-primary" wire:click="abrirModal()">Nuevo Predio</button>
        </div>

        <div class="row mb-3">
            <div class="col-md-6">
                <!-- Filtro de búsqueda -->
                <input type="text" wire:model.debounce.500ms="search" class="form-control" placeholder="Buscar..." id="searchInput">
            </div>
            <div class="col-md-6 text-end">
                <!-- Desplegable de paginación -->
                <select wire:model="perPage" class="form-select d-inline-block w-auto" id="paginationSelect">
                    <option value="5">5</option>
                    <option value="10">10</option>
                    <option value="15">15</option>
                    <option value="20">20</option>
                </select>
            </div>
        </div>
    
        @if(session()->has('success'))
            <div class="alert alert-success">{{ session('success') }}</div>
        @endif
    
        <div class="table-responsive">
            <table class="table table-striped">
                <thead class="table-light sticky-top">
                    <tr>
                        <th>Cuenta</th>
                        <th>Clave Catastral</th>
                        <th>Nombre</th>
                        <th>Domicilio Predio</th>
                        <th>Calle</th>
                        <th>Colonia</th>
                        <th>Población</th>
                        <th>Domicilio Notificación</th>
                        <th>Valor Fiscal</th>
                        <th>Tasa</th>
                        <th>Inicio</th>
                        <th>Fin</th>
                        <th>Impuesto</th>
                        <th>Recargos</th>
                        <th>Rezagos</th>
                        <th>Gastos</th>
                        <th>Multas</th>
                        <th>Adeudo</th>
                        <th>Acciones</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($predios as $predio)
                        <tr>
                            <td>{{ $predio->cuenta }}</td>
                            <td>{{ $predio->clave_catastral }}</td>
                            <td>{{ $predio->nombre }}</td>
                            <td>{{ $predio->domicilio_predio }}</td>
                            <td>{{ $predio->calle }}</td>
                            <td>{{ $predio->colonia }}</td>
                            <td>{{ $predio->poblacion }}</td>
                            <td>{{ $predio->domicilio_notificacion }}</td>
                            <td>${{ number_format($predio->valor_fiscal, 2) }}</td>
                            <td>{{ $predio->tasa }}</td>
                            <td>{{ $predio->inicio }}</td>
                            <td>{{ $predio->fin }}</td>
                            <td>${{ number_format($predio->impuesto, 2) }}</td>
                            <td>${{ number_format($predio->recargos, 2) }}</td>
                            <td>${{ number_format($predio->rezagos, 2) }}</td>
                            <td>${{ number_format($predio->gastos, 2) }}</td>
                            <td>${{ number_format($predio->multas, 2) }}</td>
                            <td>${{ number_format($predio->adeudo, 2) }}</td>
                            <td>
                                <button class="btn btn-warning btn-sm" wire:click="abrirModal({{ $predio->id }})">Editar</button>
                                <button class="btn btn-danger btn-sm" wire:click="eliminar({{ $predio->id }})">Eliminar</button>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
        
    
        <!-- Paginación -->
        <div class="d-flex justify-content-end mt-3">
            {{ $predios->links() }}
        </div>

        @if($modalVisible)
        <div class="modal fade show d-block" tabindex="-1">
            <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                        <h5 class="modal-title">{{ $modoEdicion ? 'Editar Predio' : 'Nuevo Predio' }}</h5>
                        <button type="button" class="close" wire:click="$set('modalVisible', false)">×</button>
                    </div>
                    <div class="modal-body">
                        @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                               Existen errores para procesar los
                            </ul>
                        </div>
                    @endif
                    <form id="formulario">
                        <input type="hidden" name="id" value="{{ $id }}">
                    
                        <div class="row">
                            <div class="col-md-4 mb-3">
                                <label for="cuenta" class="form-label">Cuenta</label>
                                <input type="text" class="form-control @error('cuenta') is-invalid @enderror" name="cuenta" value="{{ $modoEdicion ? $predio->cuenta : '' }}">
                                @error('cuenta')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="clave_catastral" class="form-label">Clave Catastral</label>
                                <input type="text" class="form-control @error('clave_catastral') is-invalid @enderror" name="clave_catastral" value="{{ $modoEdicion ? $predio->clave_catastral : '' }}">
                                @error('clave_catastral')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="nombre" class="form-label">Nombre</label>
                                <input type="text" class="form-control @error('nombre') is-invalid @enderror" name="nombre" value="{{ $modoEdicion ? $predio->nombre : '' }}">
                                @error('nombre')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                        <div class="row">
                            <div class="col-md-4 mb-3">
                                <label for="domicilio_predio" class="form-label">Domicilio Predio</label>
                                <input type="text" class="form-control @error('domicilio_predio') is-invalid @enderror" name="domicilio_predio" value="{{ $modoEdicion ? $predio->domicilio_predio : '' }}">
                                @error('domicilio_predio')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="calle" class="form-label">Calle</label>
                                <input type="text" class="form-control @error('calle') is-invalid @enderror" name="calle" value="{{ $modoEdicion ? $predio->calle : '' }}">
                                @error('calle')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="colonia" class="form-label">Colonia</label>
                                <input type="text" class="form-control @error('colonia') is-invalid @enderror" name="colonia" value="{{ $modoEdicion ? $predio->colonia : '' }}">
                                @error('colonia')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                        <div class="row">
                            <div class="col-md-4 mb-3">
                                <label for="poblacion" class="form-label">Población</label>
                                <input type="text" class="form-control @error('poblacion') is-invalid @enderror" name="poblacion" value="{{ $modoEdicion ? $predio->poblacion : '' }}">
                                @error('poblacion')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="domicilio_notificacion" class="form-label">Domicilio Notificación</label>
                                <input type="text" class="form-control @error('domicilio_notificacion') is-invalid @enderror" name="domicilio_notificacion" value="{{ $modoEdicion ? $predio->domicilio_notificacion : '' }}">
                                @error('domicilio_notificacion')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="valor_fiscal" class="form-label">Valor Fiscal</label>
                                <input type="number" step="0.1" class="form-control @error('valor_fiscal') is-invalid @enderror" name="valor_fiscal" value="{{ $modoEdicion ? $predio->valor_fiscal : '' }}">
                                @error('valor_fiscal')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                        <div class="row">
                            <div class="col-md-4 mb-3">
                                <label for="tasa" class="form-label">Tasa</label>
                                <input type="number" step="0.1" class="form-control @error('tasa') is-invalid @enderror" name="tasa" value="{{ $modoEdicion ? $predio->tasa : '' }}">
                                @error('tasa')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="inicio" class="form-label">Inicio</label>
                                <input type="date" class="form-control @error('inicio') is-invalid @enderror" name="inicio" value="{{ $modoEdicion ? $predio->inicio : '' }}">
                                @error('inicio')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="fin" class="form-label">Fin</label>
                                <input type="date" class="form-control @error('fin') is-invalid @enderror" name="fin" value="{{ $modoEdicion ? $predio->fin : '' }}">
                                @error('fin')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                        <div class="row">
                            @foreach(['impuesto', 'recargos', 'rezagos', 'gastos', 'multas', 'adeudo'] as $campo)
                                <div class="col-md-4 mb-3">
                                    <label for="{{ $campo }}" class="form-label">{{ ucfirst($campo) }}</label>
                                    <input type="number" step="0.1" class="form-control @error($campo) is-invalid @enderror" name="{{ $campo }}" value="{{ $modoEdicion ? $predio->$campo : '' }}">
                                    @error($campo)
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            @endforeach
                        </div>
                    
                        <button type="button" id="enviarDatos" class="btn btn-primary mt-3">Guardar</button>
                    </form>
                    
                    </div>
                </div>
            </div>
        </div>
    @endif

    @push('scripts')
    <script>
       $(document).on('click', '#enviarDatos', function () {
            var datos = {};
            $('#formulario').find('hidden, input, select, textarea').each(function () {
                datos[$(this).attr('name')] = $(this).val();
            });
            console.log(datos);
            Livewire.dispatch('datosRecibidos', { datos: datos });
        });

        // Buscador
        $('#searchInput').on('input', function() {
            @this.set('search', $(this).val()); // Actualiza el valor de la búsqueda
        });

        // Paginación
        $('#paginationSelect').on('change', function() {
            @this.set('perPage', $(this).val()); // Cambia el número de registros por página
        });

    </script>
    @endpush

</div>
