<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Gasto;
use App\Models\Permiso;
use Illuminate\Support\Facades\Auth;

class Gastos extends Component
{
    use WithPagination;

    public $gasto_id, $user_id, $valor, $estado, $responsable;
    public $modalVisible = false;
    public $modoEdicion = false;
    public $permisos = [];

    protected $listeners = ['datosRecibidos' => 'guardarGasto'];

    public function mount()
    {
        $this->user_id = Auth::id();
        $this->cargarPermisos();
    }

    private function cargarPermisos()
    {
        $permiso = Permiso::where('tabla', 'gastos')->first();
        $this->permisos = is_string($permiso->roles_permisos) ? json_decode($permiso->roles_permisos, true) : $permiso->roles_permisos;

    $rolesUsuario = is_string(Auth::user()->perfiles) ? json_decode(Auth::user()->perfiles, true): (Auth::user()->perfiles ?? []);
        foreach ($rolesUsuario as $rol) {
            if (isset($this->permisos[$rol])) {
                foreach ($this->permisos[$rol] as $permiso => $valor) {
                    $this->permisos[$permiso] = $valor;
                }
            }
        }
    }

    public function tienePermiso($accion)
    {
        return $this->permisos[$accion] ?? false;
    }

    public function abrirModal($id = null)
    {
        if ($id) {
            if (!$this->tienePermiso('editar')) return;
            
            $gasto = Gasto::findOrFail($id);
            $this->gasto_id = $gasto->id;
            $this->valor = $gasto->valor;
            $this->estado = $gasto->estado;
            $this->responsable = $gasto->responsable;
            $this->modoEdicion = true;
        } else {
            if (!$this->tienePermiso('crear')) return;
            $this->reset(['gasto_id', 'valor', 'estado', 'responsable']);
            $this->modoEdicion = false;
        }
        $this->modalVisible = true;
    }

    public function guardarGasto($datos)
    {
        $this->gasto_id = $datos['gasto_id'] ?? null;
        $this->valor = $datos['valor'];
        $this->estado = $datos['estado'];
        $this->responsable = $datos['responsable'];
        

        if ($this->modoEdicion) {
            if (!$this->tienePermiso('editar')) return;
            Gasto::where('id', $this->gasto_id)->update([
                'valor' => $this->valor,
                'estado' => $this->estado,
                'responsable' => $this->responsable
            ]);
        } else {
            if (!$this->tienePermiso('crear')) return;
            Gasto::create([
                'user_id' => $this->user_id,
                'valor' => $this->valor,
                'estado' => $this->estado,
                'responsable' => $this->responsable
            ]);
        }

        session()->flash('success', $this->modoEdicion ? 'Gasto actualizado' : 'Gasto creado');
        $this->modalVisible = false;
    }


    public function eliminar($id)
    {
        if ($this->tienePermiso('eliminar')) {
            Gasto::findOrFail($id)->delete();
            session()->flash('success', 'Gasto eliminado correctamente');
        }
    }

    public function render()
    {
        return view('livewire.gastos-component', ['gastos' => Gasto::paginate(10)]);
    }
}

