<?php

namespace App\Livewire;

use Livewire\Component;

use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;

class Login extends Component
{
    public $email, $password, $remember = false;
    protected $rules = [
        'email' => ['required', 'email'],
        'password' => ['required', 'min:6'],
    ];

    public function login(Request $request) // Inyecta la clase Request
    {
        $this->validate();

        if (Auth::attempt(['email' => $this->email, 'password' => $this->password], $this->remember)) {
            session()->regenerate();

            // Verifica si hay una URL anterior en la sesión
            if ($request->session()->has('url.intended')) {
                $urlIntended = $request->session()->pull('url.intended'); // Obtiene y elimina la URL anterior
                return redirect()->to($urlIntended); // Redirige a la URL anterior
            } else {
                return redirect()->intended('/dashboard'); // Redirige al dashboard si no hay URL anterior
            }
        }

        $this->addError('email', 'Los datos ingresados no coinciden con los registrados en nuestra base de datos.');
    }

    public function render()
    {
        return view('livewire.login');
    }
}
