<?php

namespace App\Livewire;

use Livewire\Component;
use App\Models\Modulo;

class Modulos extends Component
{
    public $formulario;
    public $valores = [];

    protected $listeners = ['datosRecibidos' => 'procesarDatos'];

    public function mount($formularioId = 1)
    {
        $this->formulario = Modulo::findOrFail($formularioId);

        foreach ($this->formulario->estructura['campos'] as $campo) {
            $this->valores[$campo['nombre']] = '';
        }
    }

    public function procesarDatos($datos)
    {
        foreach ($datos as $clave => $valor) {
            if (array_key_exists($clave, $this->valores)) {
                $this->valores[$clave] = $valor;
            }
        }
        

        $this->guardar();
    }

    public function guardar()
    {
        $this->validate($this->reglasValidacion());

        session()->flash('mensaje', 'Formulario guardado correctamente.');

        // Emitir evento para que jQuery lo capture
        $this->dispatch('formularioProcesado', [
            'tipo' => 'success',
            'titulo' => 'Bien Hecho!',
            'mensaje' => 'Formulario guardado correctamente.'
        ]);
    }

    private function reglasValidacion()
    {
        $reglas = [];

        foreach ($this->formulario->estructura['campos'] as $campo) {
            $nombreCampo = "valores.{$campo['nombre']}";
            $reglas[$nombreCampo] = [];

            if (!empty($campo['obligatorio']) && $campo['obligatorio']) {
                $reglas[$nombreCampo][] = 'required';
            }

            if ($campo['tipo'] === 'email') {
                $reglas[$nombreCampo][] = 'email';
            }

            if ($campo['tipo'] === 'number') {
                $reglas[$nombreCampo][] = "numeric";
                if (isset($campo['min'])) {
                    $reglas[$nombreCampo][] = "min:{$campo['min']}";
                }
                if (isset($campo['max'])) {
                    $reglas[$nombreCampo][] = "max:{$campo['max']}";
                }
            }
        }

        foreach ($reglas as $campo => $regla) {
            $reglas[$campo] = implode('|', $regla);
        }

        return $reglas;
    }

    public function render()
    {
        return view('livewire.modulos');
    }
}
