<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Pago;
use Illuminate\Support\Facades\Validator;

class Pagos extends Component
{
    use WithPagination;

    public $search = ''; // Variable de búsqueda
    public $perPage = 10; // Número de elementos por página
    public $modalVisible = false;
    public $modoEdicion = false;
    public $recibo, $cuenta, $predial, $recargos, $rezago, $multas;
    public $id, $gastos_cobranza, $gastos_envio, $gastos_notificacion, $importe, $descuento, $total;
    public $fecha_pago;
    public $estados = [];

    protected $listeners = ['datosRecibidos' => 'guardarPago'];

    protected function rules()
    {
        return [
        'cuenta' => 'required',
        'predial' => 'required|numeric',
        'recargos' => 'required|numeric',
        'rezago' => 'required|numeric',
        'multas' => 'required|numeric',
        'gastos_cobranza' => 'required|numeric',
        'gastos_envio' => 'required|numeric',
        'gastos_notificacion' => 'required|numeric',
        'descuento' => 'required|numeric',
        'fecha_pago' => 'required|date|before_or_equal:today',
        ];
}

    // Función para mostrar el modal de creación o edición
    public function abrirModal($id = null)
    {
        $this->resetValidation();
        if ($id) {
            $pago = Pago::findOrFail($id);
            $this->fill($pago->toArray());
            $this->modoEdicion = true;
        } else {
            $this->reset();
            $this->modoEdicion = false;
        }
        $this->modalVisible = true;
    }

    // Al actualizar la búsqueda, vuelve a la primera página
        public function updatedSearch()
        {
            $this->resetPage();
        }

        // Al cambiar la cantidad de elementos por página, vuelve a la primera página
        public function updatedPerPage()
        {
            $this->resetPage();
        }

        public function updatedestados()
        {
            $this->resetPage();
        }

    // Función para guardar el Pago
    public function guardarPago($datos)
    {
        unset($datos['recibo']);
        unset($datos['estado']);

        // Validar los datos manualmente en lugar de $this->validate()
        $validados = Validator::make($datos, $this->rules())->validate();        
        
        if ($this->modoEdicion) {
            Pago::where('id', $datos['id'])->update($validados);
            session()->flash('success', 'Pago actualizado correctamente.');
        } else {
            $validados['recibo'] = Pago::generarRecibo();
            Pago::create($validados);
            session()->flash('success', 'Pago creado correctamente.');
        }
        $this->reset();
        $this->modalVisible = false;
    }
    // Función para eliminar un Pago
    public function eliminar($id)
    {
        dd('Eliminar');
        Pago::findOrFail($id)->delete();
        session()->flash('success', 'Pago eliminado correctamente.');
    }

    // Función de renderizado
    public function render()
    {
        $pagos = Pago::query()
            ->where(function ($query) {
                // Búsqueda optimizada para buscar en cualquier campo
                $query->where('recibo', 'like', '%'.$this->search.'%')
                    ->orWhere('cuenta', 'like', '%'.$this->search.'%')
                    ->orWhere('estado', 'like', '%'.$this->search.'%')
                    ->orWhere('fecha_pago', 'like', '%'.$this->search.'%');
            })
            ->when(!empty($this->estados), function ($query) {
                // Filtro para los estados seleccionados
                return $query->whereIn('estado', $this->estados);
            })
            ->paginate($this->perPage); // Aplicar la paginación

        return view('livewire.pagos', compact('pagos'));
    }
}
