<?php

namespace App\Livewire;
use App\Models\User;
use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Predio;
use App\Models\Notificacion;
use Illuminate\Support\Facades\DB;


class Predios extends Component
{
    use WithPagination;

    public $search = ''; // Variable de búsqueda
    public $perPage = 10; // Número de elementos por página
    public $id, $cuenta, $clave_catastral, $nombre, $domicilio_predio, $calle, 
           $colonia, $poblacion, $domicilio_notificacion, $valor_fiscal, $tasa, 
           $inicio, $fin, $impuesto, $recargos, $rezagos, $gastos, $multas, $adeudo;
    public $notificadores = [];
    public $notificadorSeleccionado = [];
    public $fnotificador=null;
    public $detalles;
    public $historial;
    public $notificaciones;

    protected $listeners = ['cargarDetallesModal'=>'cargarDetallesModal', 'asignarNotificador' => 'asignarNotificador'];

    public function cargarDetallesModal($cuenta)
    {
        // Cargar los detalles del predio
        $this->detalles = Predio::where('cuenta', $cuenta)->first();

        // Cargar historial (suponiendo que haya una relación o campo para obtener el historial)
        $this->historial = Predio::where('cuenta', $cuenta)
            ->orderBy('updated_at', 'desc') // Ordenar por la fecha de actualización
            ->get(); // O algún otro criterio según tu modelo

        // Cargar las notificaciones asociadas al predio
        $this->notificaciones = Notificacion::where('cuenta', $cuenta)->get();

        // Después de que los datos se hayan cargado, abrir el modal
        $this->dispatch('abrirModal');
    }

    // Al actualizar la búsqueda, vuelve a la primera página
        public function updatedSearch()
        {
            $this->resetPage();
        }

        // Al cambiar la cantidad de elementos por página, vuelve a la primera página
        public function updatedPerPage()
        {
            $this->resetPage();
        }

    public function mount()
    {
        // Filtrar usuarios que tengan el perfil "notificador"
        $this->notificadores = User::whereJsonContains('perfiles', 'notificador')->get(['id', 'name']);
    }

    public function asignarNotificador($predioId, $notificadorId)
    {
        try {
            // Verificar si el usuario tiene el perfil "notificador"
            if($notificadorId != '*'){
                $notificador = User::where('id', $notificadorId)
                ->whereJsonContains('perfiles', 'notificador')
                ->first();

                if (!$notificador) {
                    $this->dispatch('mensaje', modo: 'error', msj: 'El usuario seleccionado no es válido.');
                    return;
                }
                 // Actualizar el predio y verificar si se afectó alguna fila
                $affectedRows = Predio::where('id', $predioId)->update(['notificador' => $notificadorId]);
                $notificadorName=$notificador->name;
            }
            else{
                 // Actualizar el predio y verificar si se afectó alguna fila
                $affectedRows = Predio::where('id', $predioId)->update(['notificador' => null]);
                $notificadorName = "Sin Signar";
            }

            if ($affectedRows === 1 &  $notificadorName === "Sin Signar") {
                $this->dispatch('mensaje', modo: 'info', msj: 'El registró quedó sin notificador asignado.');
            } 
            elseif ($affectedRows === 1) {
                $this->dispatch('mensaje', modo: 'ok', msj: 'Se asignó correctamente a: ' . $notificadorName);
            }
            else {
                $this->dispatch('mensaje', modo: 'error', msj: 'No se realizó la asignación. Verifica los datos.');
            }
            $this->skipRender();

        } catch (\Exception $e) {
            $this->dispatch('mensaje', modo: 'error', msj: 'Error: ' . $e->getMessage());
        }
    }

    


    // Función de renderizado
    public function render()
    {
        $predios = Predio::query()
        ->select('predios.*')
        ->join(
            DB::raw('(SELECT MAX(id) as id FROM predios GROUP BY cuenta) as ultimos'),
            'predios.id', '=', 'ultimos.id'
        )
        ->when($this->fnotificador === 'vacio', function ($query) {
            return $query->whereNull('notificador')->orWhere('notificador', '');
        })
        ->when(!empty($this->fnotificador) && $this->fnotificador !== 'vacio', function ($query) {
            return $query->where('notificador', $this->fnotificador);
        })
        ->where(function ($query) {
            $query->where('cuenta', 'like', '%'.$this->search.'%')
                ->orWhere('clave_catastral', 'like', '%'.$this->search.'%')
                ->orWhere('nombre', 'like', '%'.$this->search.'%')
                ->orWhere('domicilio_predio', 'like', '%'.$this->search.'%')
                ->orWhere('calle', 'like', '%'.$this->search.'%')
                ->orWhere('colonia', 'like', '%'.$this->search.'%')
                ->orWhere('poblacion', 'like', '%'.$this->search.'%');
        })
        ->paginate($this->perPage);
    

        return view('livewire.predios', compact('predios'));
    }
}
