<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithFileUploads;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\PrediosImport;
use Maatwebsite\Excel\Validators\ValidationException;
use App\Models\PredioImport;
use Livewire\WithPagination;

class PrediosExcelCargar extends Component
{
    use WithFileUploads, WithPagination;

    public $file;
    public $perPage = 10;

    /**
     * Cargar el archivo y procesarlo
     */
    public function updatedPerPage()
        {
            $this->resetPage();
        }

     public function updatedFile()
     {
        $this->skipRender();
     }
    public function import()
    {
        // Validar archivo
        $this->validate([
            'file' => 'required|mimes:xlsx,xls,csv|max:10240', // Máximo 10MB
        ]);

        try {
            // Importar archivo
            Excel::import(new PrediosImport, $this->file->getRealPath());

            // Limpiar input de archivo
            $this->reset('file');

            // Mensaje de éxito y recargar página
            session()->flash('message', 'Archivo cargado y procesado exitosamente.');
            return redirect(request()->header('Referer'));
        } catch (ValidationException $e) {
            // Capturar errores de validación de Excel
            foreach ($e->errors() as $error) {
                $this->addError('file', implode(', ', $error));
            }
        } catch (\Exception $e) {
            // Capturar cualquier otro error
            session()->flash('error', $e->getMessage());
        }
    }

    public function render()
    {
        $predios = PredioImport::paginate($this->perPage);
        return view('livewire.predios-excel-cargar', compact('predios'));
    }
}
