<?php

namespace App\Livewire;

use Livewire\Component;
use App\Models\Formularios;

class Primero extends Component
{
    public $formulario;
    public $valores = [];

    protected $listeners = ['datosRecibidos' => 'procesarDatos'];

    public function mount($formularioId = 1)
    {
        // Cargar formulario desde la base de datos
        $this->formulario = Formularios::findOrFail($formularioId);

        // Inicializar valores de los campos con estructura JSON
        foreach ($this->formulario->estructura['campos'] as $campo) {
            $this->valores[$campo['nombre']] = '';
        }
    }

    public function procesarDatos($datos)
    {

        $this->valores = array_merge($this->valores, $datos['datos'] ?? []);
        $this->guardar();
    }

    public function guardar()
    {
    
    $this->validate($this->reglasValidacion());
    
    $this->dispatch('formularioProcesado', [
        'status' => 'success',
        'message' => 'Formulario guardado correctamente.'
    ]);
    }

    private function reglasValidacion()
    {
    $reglas = [];

    foreach ($this->formulario->estructura['campos'] as $campo) {
        $nombreCampo = "valores.{$campo['nombre']}";
        $validaciones = [];

        if (!empty($campo['obligatorio']) && $campo['obligatorio']) {
            $validaciones[] = 'required';
        }

        if ($campo['tipo'] === 'email') {
            $validaciones[] = 'email';
        }

        if ($campo['tipo'] === 'number') {
            $validaciones[] = 'numeric';
            if (isset($campo['min'])) {
                $validaciones[] = "min:{$campo['min']}";
            }
            if (isset($campo['max'])) {
                $validaciones[] = "max:{$campo['max']}";
            }
        }

        // Solo agregar si tiene reglas
        if (!empty($validaciones)) {
            $reglas[$nombreCampo] = $validaciones;
        }
    }

    return $reglas;
}


    public function render()
    {
        return view('livewire.primero');
    }
}
