<?php

namespace App\Livewire;

use App\Models\User;
use Livewire\Component;
use Livewire\WithPagination;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;

class Usuarios extends Component
{
    use WithPagination;

    public $search = '';
    public $perPage = 10;
    public $perfilesDisponibles = ['admin', 'notificador', 'supervisor'];
    public $user;
    public $modalVisible = false;
    public $modoEdicion = false;
    public $id, $name, $email, $tema, $perfiles;


    protected $listeners = ['abrirModal' => 'abrirModal', 'guardarUsuario'=>'actualizarUsuario'];

    protected function rules()
    {
        return [
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255|unique:users,email,' . $this->id,
            'password' => $this->modoEdicion ? 'nullable|string|min:8' : 'required|string|min:8',
            'perfiles' => 'required',
            'tema' => 'required|in:quartz,lumen,minty,cerulean,cosmo,cyborg,darkly,flatly,journal,litera,lux,materia,morph,pulse,sandstone,simplex,sketchy,slate,solar,spacelab,superhero,united,vapor,yeti,zephyr',
        ];
    }

 

    public function loginAsUser($userId)
    {
        $usuario = auth()->user();
        if (!in_array('admin', $usuario->perfiles ?? [])) {
            $this->dispatch('mensaje', modo: 'error', msj: 'No tienes el perfil para hacer esto.');
            return;
        }

        Auth::loginUsingId($userId);

        return redirect()->route('dashboard'); // Cambia a la ruta de inicio que prefieras
    }



    public function updatedSearch()
    {
        $this->resetPage();
    }

    public function updatedPerPage()
    {
        $this->resetPage();
    }
    public function mount()
        {
            // Obtener el usuario autenticado
            $usuario = auth()->user();

            // Verificar si tiene el perfil de admin
            if (!in_array('admin', $usuario->perfiles ?? [])) {
                return redirect()->route('dashboard'); // Redirigir al dashboard si no es admin
            }
        }


    public function abrirModal($id = null)
    {
        $this->resetErrorBag();
        if ($id) {
            $user = User::findOrFail($id);
            $this->user = $user;
            $this->id = $user->id;
            $this->fill($user->toArray());
            $this->modoEdicion = true;
        } else {
            $this->reset();
            $this->modoEdicion = false;
        }
        $this->modalVisible = true;
    }

    public function cargarUsuario($id)
    {
        $usuario =  User::find($id);
        if (!$usuario) {
            $this->dispatch('mensaje', modo: 'error', msj: 'Usuario no encontrado.');
            return;
        }
        $this->usuarioel = $usuario;
        
        $this->dispatch('abrirModal');
    }

    public function actualizarUsuario($datos)
    {
        $validados = Validator::make($datos, $this->rules())->validate();

        // Si la contraseña viene vacía, la eliminamos del array de datos validados
        if (empty($validados['password'])) {
            unset($validados['password']);
        } else {
            $validados['password'] = bcrypt($validados['password']); // Encriptar la contraseña
        }

        $validados['perfiles'] = (array) $validados['perfiles'];
        $validados['aditional_info'] = json_encode(['tema' => $validados['tema']]);
        unset($validados['tema']);

        try {
            if ($this->modoEdicion) {
                User::where('id', $this->id)->update($validados);
                $this->dispatch('mensaje', modo: 'ok', msj: 'Usuario actualizado correctamente.');
            } else {
                User::create($validados);
                $this->dispatch('mensaje', modo: 'ok', msj: 'Usuario creado correctamente.');
            }

            $this->modalVisible = false;
            $this->resetPage();
        } catch (\Exception $e) {
            $this->dispatch('mensaje', modo: 'error', msj: 'Error: ' . $e->getMessage());
        }
    }



    public function render()
    {
        $usuarios = User::where('name', 'like', "%{$this->search}%")
            ->orWhere('email', 'like', "%{$this->search}%")
            ->paginate($this->perPage);

        return view('livewire.usuarios', compact('usuarios'));
    }
}

