<?php

namespace App\Livewire;
use App\Models\User;
use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Predio;
use App\Models\Notificacion;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;


class VerNotificaciones extends Component
{
    use WithPagination;

    public $search = ''; // Variable de búsqueda
    public $perPage = 10; // Número de elementos por página
    
    public $id, $cuenta, $tipo_visita, $supervisor, $ejecutor, $fecha, $estado, $observaciones, $fecha_visita;
    public $notificadores = [];
    public $user = [];
    public $notificadorSeleccionado = [];
    public $fnotificador=null;
    public $detalles;
    public $historial;
    public $edit_notificacion;

    protected $listeners = ['cargarNotificacion'=>'cargarNotificacion','cargarDetallesModal'=>'cargarDetallesModal', 'asignarNotificador' => 'asignarNotificador'];

    public function cargarDetallesModal($cuenta)
    {
        // Cargar los detalles del predio
        $this->detalles = Predio::where('cuenta', $cuenta)->first();

        // Cargar historial (suponiendo que haya una relación o campo para obtener el historial)
        $this->historial = Predio::where('cuenta', $cuenta)
            ->orderBy('updated_at', 'desc') // Ordenar por la fecha de actualización
            ->get(); // O algún otro criterio según tu modelo

        // Cargar las notificaciones asociadas al predio
        $this->notificaciones = Notificacion::where('cuenta', $cuenta)->get();

        // Después de que los datos se hayan cargado, abrir el modal
        $this->dispatch('abrirModal');
    }

   
    // Al actualizar la búsqueda, vuelve a la primera página
        public function updatedSearch()
        {
            $this->resetPage();
        }

        // Al cambiar la cantidad de elementos por página, vuelve a la primera página
        public function updatedPerPage()
        {
            $this->resetPage();
        }

    public function mount()
    {
        // Filtrar usuarios que tengan el perfil "notificador"
        $this->notificadores = User::whereJsonContains('perfiles', 'notificador')->get(['id', 'name']);
        $this->user =  auth()->user();;
    }

    

    // Función de renderizado
    public function render()
    {

        $notificaciones = Notificacion::select('notificaciones.*', 'supervisores.name as supervisor_nombre',
                        'ejecutores.name as ejecutor_nombre')
                    ->leftJoin('users as supervisores', 'notificaciones.supervisor', '=', 'supervisores.id')
                    ->leftJoin('users as ejecutores', 'notificaciones.ejecutor', '=', 'ejecutores.id')
                    ->orderBy('notificaciones.id', 'desc')
                    ->paginate($this->perPage);
    
           
        return view('livewire.ver-notificaciones', compact('notificaciones'));
    }
}
