<?php
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    public function up()
    {
        Schema::create('predios', function (Blueprint $table) {
            $table->id(); // Crea un campo de tipo bigInteger y lo establece como llave primaria
            $table->string('cuenta'); // Campo cuenta único
            $table->string('clave_catastral'); // Campo para la clave catastral
            $table->string('nombre'); // Campo para el nombre del predio
            $table->string('domicilio_predio'); // Dirección del predio
            $table->string('calle'); // Calle donde se encuentra el predio
            $table->string('colonia'); // Colonia o barrio donde está el predio
            $table->string('poblacion'); // Población en la que se encuentra
            $table->string('domicilio_notificacion'); // Domicilio para notificaciones
            $table->decimal('valor_fiscal', 15, 2); // Valor fiscal con 2 decimales
            $table->decimal('tasa', 5, 2); // Tasa con 2 decimales
            $table->date('inicio'); // Fecha de inicio
            $table->date('fin'); // Fecha de fin
            $table->decimal('impuesto', 15, 2); // Campo para el impuesto con 2 decimales
            $table->decimal('recargos', 15, 2); // Campo para los recargos con 2 decimales
            $table->decimal('rezagos', 15, 2); // Campo para los rezagos con 2 decimales
            $table->decimal('gastos', 15, 2); // Campo para los gastos con 2 decimales
            $table->decimal('multas', 15, 2); // Campo para las multas con 2 decimales
            $table->decimal('adeudo', 15, 2); // Campo para el adeudo con 2 decimales
            $table->integer('historico')->nullable(); // Campo para el histórico
            $table->integer('notificador')->nullable(); // Campo para el notificador
            $table->integer('creado_por')->nullable(); // Campo para la persona que creó el registro
            $table->timestamps(); // Campos de timestamps (created_at, updated_at)
        });

        DB::table('predios')->insert([
            [
                'cuenta' => 'U002603',
                'clave_catastral' => '14-002-018-01-0001-002-302-00016-00-0000',
                'nombre' => 'GARCIA LOPEZ JUAN',
                'domicilio_predio' => 'AV. JUAREZ 35, COL.: CENTRO, POB.: LA BARCA',
                'calle' => 'AV. JUAREZ 35',
                'colonia' => 'COL.: CENTRO',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE DE LA LUZ 21, COL.: LAS PALMAS, POB.: LA BARCA',
                'valor_fiscal' => 51480000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-02-01',
                'fin' => '2025-02-19',
                'impuesto' => 8200.00,
                'recargos' => 500.00,
                'rezagos' => 0.00,
                'gastos' => 100.00,
                'multas' => 50.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002603',
                'clave_catastral' => '14-002-019-02-0002-003-303-00017-00-0000',
                'nombre' => 'HERNANDEZ MARTINEZ ANA',
                'domicilio_predio' => 'CALLE HIDALGO 10, COL.: SAN MIGUEL, POB.: TLAQUEPAQUE',
                'calle' => 'CALLE HIDALGO 10',
                'colonia' => 'COL.: SAN MIGUEL',
                'poblacion' => 'POB.: TLAQUEPAQUE',
                'domicilio_notificacion' => 'AV. INDEPENDENCIA 120, COL.: LAS FUENTES, POB.: TLAQUEPAQUE',
                'valor_fiscal' => 32050000.00,
                'tasa' => 0.00015,
                'inicio' => '2024-01-15',
                'fin' => '2025-01-15',
                'impuesto' => 5200.00,
                'recargos' => 300.00,
                'rezagos' => 100.00,
                'gastos' => 80.00,
                'multas' => 40.00,
                'adeudo' => 100.00,
                'historico' => 1,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002603',
                'clave_catastral' => '14-003-020-03-0003-004-304-00018-00-0000',
                'nombre' => 'LOPEZ PEREZ MARIA',
                'domicilio_predio' => 'AV. MORELOS 150, COL.: EL CARMEN, POB.: TEPATITLÁN',
                'calle' => 'AV. MORELOS 150',
                'colonia' => 'COL.: EL CARMEN',
                'poblacion' => 'POB.: TEPATITLÁN',
                'domicilio_notificacion' => 'CALLE BENITO JUÁREZ 45, COL.: CENTRO, POB.: TEPATITLÁN',
                'valor_fiscal' => 41070000.00,
                'tasa' => 0.00017,
                'inicio' => '2024-03-10',
                'fin' => '2025-03-10',
                'impuesto' => 6900.00,
                'recargos' => 450.00,
                'rezagos' => 50.00,
                'gastos' => 120.00,
                'multas' => 60.00,
                'adeudo' => 50.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002606',
                'clave_catastral' => '14-004-021-04-0004-005-305-00019-00-0000',
                'nombre' => 'RAMIREZ GOMEZ CARLOS',
                'domicilio_predio' => 'CALLE 5 DE MAYO 85, COL.: SAN PEDRO, POB.: ZAPOPAN',
                'calle' => 'CALLE 5 DE MAYO 85',
                'colonia' => 'COL.: SAN PEDRO',
                'poblacion' => 'POB.: ZAPOPAN',
                'domicilio_notificacion' => 'AV. GUADALUPE 210, COL.: CHAPALITA, POB.: ZAPOPAN',
                'valor_fiscal' => 57000000.00,
                'tasa' => 0.00020,
                'inicio' => '2024-04-05',
                'fin' => '2025-04-05',
                'impuesto' => 9800.00,
                'recargos' => 600.00,
                'rezagos' => 200.00,
                'gastos' => 150.00,
                'multas' => 80.00,
                'adeudo' => 200.00,
                'historico' => 1,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002607',
                'clave_catastral' => '14-005-022-05-0005-006-306-00020-00-0000',
                'nombre' => 'TORRES SANDOVAL LUIS',
                'domicilio_predio' => 'AV. UNIVERSIDAD 95, COL.: LAS TORRES, POB.: GUADALAJARA',
                'calle' => 'AV. UNIVERSIDAD 95',
                'colonia' => 'COL.: LAS TORRES',
                'poblacion' => 'POB.: GUADALAJARA',
                'domicilio_notificacion' => 'CALLE MORELOS 250, COL.: CENTRO, POB.: GUADALAJARA',
                'valor_fiscal' => 44530000.00,
                'tasa' => 0.00019,
                'inicio' => '2024-05-20',
                'fin' => '2025-05-20',
                'impuesto' => 7900.00,
                'recargos' => 500.00,
                'rezagos' => 120.00,
                'gastos' => 110.00,
                'multas' => 50.00,
                'adeudo' => 120.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],            
            [
                'cuenta' => 'U002104',
                'clave_catastral' => '14-002-018-01-0001-003-302-00017-00-0000',
                'nombre' => 'MARTINEZ RIVERA ANTONIO',
                'domicilio_predio' => 'CALLE FRESNO 18, COL.: SAN ISIDRO, POB.: LA BARCA',
                'calle' => 'CALLE FRESNO 18',
                'colonia' => 'COL.: SAN ISIDRO',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE PRINCIPAL 12, COL.: SAN ISIDRO, POB.: LA BARCA',
                'valor_fiscal' => 33500000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-03-01',
                'fin' => '2025-02-19',
                'impuesto' => 5400.00,
                'recargos' => 320.00,
                'rezagos' => 0.00,
                'gastos' => 60.00,
                'multas' => 30.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002w605',
                'clave_catastral' => '14-002-018-01-0001-004-302-00018-00-0000',
                'nombre' => 'SANDOVAL PEREZ MARIA',
                'domicilio_predio' => 'PASEO DEL SOL 22, COL.: LA LOMA, POB.: LA BARCA',
                'calle' => 'PASEO DEL SOL 22',
                'colonia' => 'COL.: LA LOMA',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'PASEO DE LOS VIENTOS 19, COL.: LA LOMA, POB.: LA BARCA',
                'valor_fiscal' => 24500000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-04-01',
                'fin' => '2025-02-19',
                'impuesto' => 4000.00,
                'recargos' => 250.00,
                'rezagos' => 0.00,
                'gastos' => 120.00,
                'multas' => 80.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U00260y6',
                'clave_catastral' => '14-002-018-01-0001-005-302-00019-00-0000',
                'nombre' => 'PEREZ GOMEZ LUISA',
                'domicilio_predio' => 'AV. 5 DE FEBRERO 89, COL.: EL ROSARIO, POB.: LA BARCA',
                'calle' => 'AV. 5 DE FEBRERO 89',
                'colonia' => 'COL.: EL ROSARIO',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE MORELOS 17, COL.: EL ROSARIO, POB.: LA BARCA',
                'valor_fiscal' => 78500000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-05-01',
                'fin' => '2025-02-19',
                'impuesto' => 12650.00,
                'recargos' => 450.00,
                'rezagos' => 0.00,
                'gastos' => 180.00,
                'multas' => 90.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U00260wq7',
                'clave_catastral' => '14-002-018-01-0001-006-302-00020-00-0000',
                'nombre' => 'FLORES HERRERA EDUARDO',
                'domicilio_predio' => 'CALLE LIRIO 17, COL.: JARDINES, POB.: LA BARCA',
                'calle' => 'CALLE LIRIO 17',
                'colonia' => 'COL.: JARDINES',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE ROSARIO 23, COL.: JARDINES, POB.: LA BARCA',
                'valor_fiscal' => 42950000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-06-01',
                'fin' => '2025-02-19',
                'impuesto' => 6830.00,
                'recargos' => 500.00,
                'rezagos' => 0.00,
                'gastos' => 90.00,
                'multas' => 40.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002608',
                'clave_catastral' => '14-002-018-01-0001-007-302-00021-00-0000',
                'nombre' => 'RAMIREZ DIAZ CLAUDIA',
                'domicilio_predio' => 'CERRADA DE LA LUNA 14, COL.: LOMAS, POB.: LA BARCA',
                'calle' => 'CERRADA DE LA LUNA 14',
                'colonia' => 'COL.: LOMAS',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE DE LA LUZ 17, COL.: LOMAS, POB.: LA BARCA',
                'valor_fiscal' => 31200000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-07-01',
                'fin' => '2025-02-19',
                'impuesto' => 4980.00,
                'recargos' => 370.00,
                'rezagos' => 0.00,
                'gastos' => 75.00,
                'multas' => 60.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002609',
                'clave_catastral' => '14-002-018-01-0001-008-302-00022-00-0000',
                'nombre' => 'GUTIERREZ MARTINEZ FRANCISCO',
                'domicilio_predio' => 'CARR. DE LA LAGUNA 43, COL.: EL MIRADOR, POB.: LA BARCA',
                'calle' => 'CARR. DE LA LAGUNA 43',
                'colonia' => 'COL.: EL MIRADOR',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE MEXICANA 19, COL.: EL MIRADOR, POB.: LA BARCA',
                'valor_fiscal' => 56350000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-08-01',
                'fin' => '2025-02-19',
                'impuesto' => 9060.00,
                'recargos' => 430.00,
                'rezagos' => 0.00,
                'gastos' => 110.00,
                'multas' => 70.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002610',
                'clave_catastral' => '14-002-018-01-0001-009-302-00023-00-0000',
                'nombre' => 'CASTRO VELAZQUEZ MARTA',
                'domicilio_predio' => 'CALLE ROSALES 10, COL.: BELLO VISTA, POB.: LA BARCA',
                'calle' => 'CALLE ROSALES 10',
                'colonia' => 'COL.: BELLO VISTA',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'AV. PRINCIPAL 22, COL.: BELLO VISTA, POB.: LA BARCA',
                'valor_fiscal' => 32210000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-09-01',
                'fin' => '2025-02-19',
                'impuesto' => 5200.00,
                'recargos' => 390.00,
                'rezagos' => 0.00,
                'gastos' => 80.00,
                'multas' => 50.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
            [
                'cuenta' => 'U002611',
                'clave_catastral' => '14-002-018-01-0001-010-302-00024-00-0000',
                'nombre' => 'VILLANUEVA PONCE ROSA',
                'domicilio_predio' => 'AV. LUIS DONALDO COLOSIO 5, COL.: EL VIVERO, POB.: LA BARCA',
                'calle' => 'AV. LUIS DONALDO COLOSIO 5',
                'colonia' => 'COL.: EL VIVERO',
                'poblacion' => 'POB.: LA BARCA',
                'domicilio_notificacion' => 'CALLE 5 DE FEBRERO 10, COL.: EL VIVERO, POB.: LA BARCA',
                'valor_fiscal' => 44100000.00,
                'tasa' => 0.00018,
                'inicio' => '2024-10-01',
                'fin' => '2025-02-19',
                'impuesto' => 7040.00,
                'recargos' => 520.00,
                'rezagos' => 0.00,
                'gastos' => 140.00,
                'multas' => 60.00,
                'adeudo' => 0.00,
                'historico' => 0,
                'created_at' => now(),
                'updated_at' => now(),
            ],
        ]);
        
        
        
        
    }

    public function down()
    {
        Schema::dropIfExists('predios');
    }
};

