<div>
    <div class="d-flex justify-content-between mb-3">
        <h3>Gestión de Gastos</h3>
        @if($this->tienePermiso('crear'))
            <button class="btn btn-primary" wire:click="abrirModal()">Nuevo Gasto</button>
        @endif
    </div>

    @if(session()->has('success'))
        <div class="alert alert-success">{{ session('success') }}</div>
    @endif

    @if(session()->has('error'))
        <div class="alert alert-danger">{{ session('error') }}</div>
    @endif

    <table class="table table-striped">
        <thead>
            <tr>
                <th>Valor</th>
                <th>Estado</th>
                <th>Responsable</th>
                <th>Acciones</th>
            </tr>
        </thead>
        <tbody>
            @foreach($gastos as $gasto)
                <tr>
                    <td>${{ number_format($gasto->valor, 2) }}</td>
                    <td>{{ $gasto->estado }}</td>
                    <td>{{ $gasto->responsable }}</td>
                    <td>
                        @if($this->tienePermiso('editar'))
                            <button class="btn btn-warning" wire:click="abrirModal({{ $gasto->id }})">Editar</button>
                        @endif
                        @if($this->tienePermiso('eliminar'))
                            <button class="btn btn-danger" wire:click="eliminar({{ $gasto->id }})">Eliminar</button>
                        @endif
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>

    {{ $gastos->links() }}

    @if($modalVisible)
        <div class="modal fade show d-block" tabindex="-1">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">{{ $modoEdicion ? 'Editar Gasto' : 'Nuevo Gasto' }}</h5>
                        <button type="button" class="close" wire:click="$set('modalVisible', false)">×</button>
                    </div>
                    <div class="modal-body">
                        <form id="formulario">
                            <input type="hidden" id="gasto_id" name="gasto_id" value="{{ $gasto_id }}">

                            <label>Valor</label>
                            <input type="number" name="valor" class="form-control" value="{{ $valor }}">

                            <label>Estado</label>
                            <select name="estado" class="form-control">
                                <option {{ $estado == 'Pagada' ? 'selected' : '' }}>Pagada</option>
                                <option {{ $estado == 'Pendiente' ? 'selected' : '' }}>Pendiente</option>
                                <option {{ $estado == 'Aplazada' ? 'selected' : '' }}>Aplazada</option>
                                <option {{ $estado == 'Cancelada' ? 'selected' : '' }}>Cancelada</option>
                            </select>

                            <label>Responsable</label>
                            <input type="text" name="responsable" class="form-control" value="{{ $responsable }}">

                            <button type="button" id="enviarDatos" class="btn btn-primary mt-3">Guardar</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    @endif
    @push('scripts')
<script>
    $(document).on('click', '#enviarDatos', function () {
        var datos = {};

        $('#formulario').find('input, select, textarea').each(function () {
            var nombre = $(this).attr('name');
            var valor = $(this).val();
            datos[nombre] = valor;
        });

        Livewire.dispatch('datosRecibidos', { datos: datos });
    });
</script>
@endpush
</div>

