<div>
        <div class="row d-flex justify-content-center">
            <div id="error-alert" class="d-none">
                @error('*')
                    <span class="error-message">{{ $message }}</span>
                @enderror
            </div>
            <div class="col-md-6 col-12">
                <form id="formulario">
                    @foreach($formulario['estructura']['campos'] as $campo)
                        <div class="mb-2">
                            <label for="{{ $campo['nombre'] }}">{{ $campo['etiqueta'] ?? ucfirst($campo['nombre']) }}</label>
                            @if($campo['tipo'] === 'select' && !empty($campo['opciones']))
                                <select id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}" class="form-control">
                                    <option value="">Seleccione...</option>
                                    @foreach($campo['opciones'] as $opcion)
                                        <option value="{{ $opcion }}">{{ $opcion }}</option>
                                    @endforeach
                                </select>

                            @elseif($campo['tipo'] === 'coordenadas')
                                <input type="text" id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}" class="form-control" placeholder="Latitud, Longitud">

                            @elseif($campo['tipo'] === 'date')
                                <input type="date" id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}" class="form-control">

                            @elseif($campo['tipo'] === 'color')
                                <input type="color" id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}" class="form-control form-control-color">

                            @elseif($campo['tipo'] === 'radio' && !empty($campo['opciones']))
                                <div>
                                    @foreach($campo['opciones'] as $opcion)
                                        <div class="form-check">
                                            <input class="form-check-input" type="radio" id="{{ $campo['nombre'] }}_{{ $opcion }}" name="{{ $campo['nombre'] }}" value="{{ $opcion }}">
                                            <label class="form-check-label" for="{{ $campo['nombre'] }}_{{ $opcion }}">
                                                {{ $opcion }}
                                            </label>
                                        </div>
                                    @endforeach
                                </div>

                            @elseif($campo['tipo'] === 'checkbox' && empty($campo['opciones']))
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}">
                                    <label class="form-check-label" for="{{ $campo['nombre'] }}">
                                        {{ $campo['etiqueta'] }}
                                    </label>
                                </div>

                            @elseif($campo['tipo'] === 'range')
                                <input type="range" id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}" class="form-range" min="{{ $campo['min'] ?? 0 }}" max="{{ $campo['max'] ?? 100 }}">

                            @else
                                <input type="{{ $campo['tipo'] }}" id="{{ $campo['nombre'] }}" name="{{ $campo['nombre'] }}" class="form-control">
                            @endif

                            @error("valores.{$campo['nombre']}") 
                                <span class="text-danger">{{ $message }}</span> 
                            @enderror
                        </div>
                    @endforeach

                    <button type="button" class="btn btn-primary" id="enviarDatos">Enviar Datos</button>
                </form>
            </div>
        </div>

    @push('scripts')
        <script>
            $(document).ready(function() {
                toastr.options = {
                "closeButton": false,
                "debug": false,
                "newestOnTop": true,
                "progressBar": true,
                "positionClass": "toast-top-right",
                "preventDuplicates": false,
                "onclick": null,
                "showDuration": "300",
                "hideDuration": "1000",
                "timeOut": "5000",
                "extendedTimeOut": "1000",
                "showEasing": "swing",
                "hideEasing": "linear",
                "showMethod": "fadeIn",
                "hideMethod": "fadeOut"
                }

                $('#enviarDatos').click(function() {
                    var datos = {};
                    
                    $('#formulario').find('input, select, textarea').each(function() {
                        var tipo = $(this).attr('type');
                        var nombre = $(this).attr('name');

                        if (tipo === 'checkbox') {
                            datos[nombre] = $(this).is(':checked') ? 1 : 0;
                        } else if (tipo === 'radio') {
                            if ($(this).is(':checked')) {
                                datos[nombre] = $(this).val();
                            }
                        } else {
                            datos[nombre] = $(this).val();
                        }
                    });
                    
                    Livewire.dispatch('datosRecibidos', { datos: datos });
                });

                // Captura el evento desde Livewire para mostrar mensaje con jQuery
                Livewire.on('formularioProcesado', function(data) {
                    console.log(data); // Verifica qué datos llegan en la consola

                    if (Array.isArray(data) && data.length > 0) {
                        let obj = data[0]; // Accede al primer elemento del array

                        if (obj.tipo && obj.mensaje) {
                            toastr[obj.tipo](obj.mensaje, obj.titulo || "Notificación");
                        } else {
                            toastr["error"]("Datos inválidos en la respuesta.", "Error");
                        }
                    } else {
                        toastr["error"]("Respuesta inesperada del servidor.", "Error");
                    }
                });



            });

            

            
                
        </script>
    @endpush
</div>
