<div>
    @push('styles')
    <style>
        /* Asegura que el encabezado de la tabla se mantenga fijo */
        .sticky-top {
            position: sticky;
            top: 0;
            z-index: 2;
        }

        /* Evita el salto de línea en las celdas */
        .table td, .table th {
            white-space: nowrap;
            vertical-align: middle;
        }

        /* Ajusta la tabla para que no tenga scroll vertical */
        .table-responsive {
            overflow-x: auto; /* Permite scroll horizontal si es necesario */
            max-height: none;  /* Quita el scroll vertical */
        }
    </style>

    
    @endpush

    <div>

        <div class="d-flex justify-content-between mb-3">
            <h3>Gestión de pagos</h3>
            <button class="btn btn-primary" wire:click="abrirModal()">Nuevo pago</button>
        </div>

        <div class="row mb-3">
            <div class="col-md-4">
                <!-- Filtro de búsqueda -->
                <input type="text" wire:model.debounce.500ms="search" class="form-control" placeholder="Buscar..." id="searchInput">
            </div>
            <div class="col-md-4">
                <!-- Filtro de estado -->
                <div class="dropdown">
                    <button class="btn btn-primary dropdown-toggle" type="button" id="dropdownEstados" data-bs-toggle="dropdown" aria-expanded="false">
                        Seleccionar Estados
                    </button>
                    <ul class="dropdown-menu" aria-labelledby="dropdownEstados" id="estadosSelect">
                        <li>
                            <a class="dropdown-item">
                                <input type="checkbox" class="form-check-input" value="pendiente"> Pendiente
                            </a>
                        </li>
                        <li>
                            <a class="dropdown-item">
                                <input type="checkbox" class="form-check-input" value="eliminado"> Eliminado
                            </a>
                        </li>
                        <li>
                            <a class="dropdown-item">
                                <input type="checkbox" class="form-check-input" value="aprobado"> Aprobado
                            </a>
                        </li>
                        <li>
                            <a class="dropdown-item">
                                <input type="checkbox" class="form-check-input" value="contactado"> Contactado
                            </a>
                        </li>
                    </ul>
                </div>
                
                
            </div>
            
            <div class="col-md-4 text-end">
                <!-- Desplegable de paginación -->
                <select wire:model="perPage" class="form-select d-inline-block w-auto" id="paginationSelect">
                    <option value="5">5</option>
                    <option value="10">10</option>
                    <option value="15">15</option>
                    <option value="20">20</option>
                </select>
            </div>
        </div>
    
        @if(session()->has('success'))
            <div class="alert alert-success">{{ session('success') }}</div>
        @endif
    
        <div class="table-responsive">
            <table class="table table-striped">
                <thead class="table-light sticky-top">
                    <tr>
                        <th>Recibo</th>
                        <th>Cuenta</th>
                        <th>Predial</th>
                        <th>Recargos</th>
                        <th>Rezago</th>
                        <th>Multas</th>
                        <th>Gastos Cobranza</th>
                        <th>Gastos Envio</th>
                        <th>Gastos Notificación</th>
                        <th>Importe</th>
                        <th>Descuento</th>
                        <th>Total</th>
                        <th>Fecha Pago</th>
                        <th>Estado</th>
                        <th>Acciones</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($pagos as $pago)
                        <tr>
                            <td>{{ $pago->recibo }}</td>
                            <td>{{ $pago->cuenta }}</td>
                            <td>{{ $pago->predial }}</td>
                            <td>{{ $pago->recargos }}</td>
                            <td>{{ $pago->rezago }}</td>
                            <td>{{ $pago->multas }}</td>
                            <td>{{ $pago->gastos_cobranza }}</td>
                            <td>{{ $pago->gastos_envio }}</td>
                            <td>{{ $pago->gastos_notificacion }}</td>
                            <td>${{ number_format($pago->importe, 2) }}</td>
                            <td>{{  number_format($pago->descuento, 2) }}</td>
                            <td>{{  number_format($pago->total, 2) }}</td>
                            <td>{{ $pago->fecha_pago }}</td>
                            <td>{{ $pago->estado }}</td>
                            <td>
                                <button class="btn btn-warning btn-sm" wire:click="abrirModal({{ $pago->id }})">Editar</button>
                                <button class="btn btn-danger btn-sm" wire:click="eliminar({{ $pago->id }})">Eliminar</button>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    
        <!-- Paginación -->
        <div class="d-flex justify-content-end mt-3">
            {{ $pagos->links() }}
        </div>

        @if($modalVisible)
        <div class="modal fade show d-block" tabindex="-1">
            <div class="modal-dialog modal-lg">
                <div class="modal-content">
                    <div class="modal-header d-flex justify-content-between">
                        <h5 class="modal-title">{{ $modoEdicion ? 'Editar pago' : 'Nuevo pago' }}</h5>
                        <button type="button" class="close" wire:click="$set('modalVisible', false)"aria-label="Close"><span aria-hidden="true">&times;</span></button>
                    </div>
                    <div class="modal-body">
                        @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                               Existen errores al momento de ingresar un pago.
                            </ul>
                        </div>
                    @endif
                    <form id="formulario">
                        <input type="hidden" name="id" value="{{ $id }}">
                    
                        <div class="row ">
                            <div class="col-md-4 mb-3">
                                <label for="cuenta" class="form-label">Cuenta</label>
                                <input type="text" class="form-control @error('cuenta') is-invalid @enderror" name="cuenta" value="{{ $modoEdicion ? $pago->cuenta : '' }}">
                                @error('cuenta')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="valor_fiscal" class="form-label">Predial</label>
                                <input type="number" step="0.1" class="form-control @error('predial') is-invalid @enderror" name="predial" value="{{ $modoEdicion ? $pago->predial : '' }}">
                                @error('predial')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="recargos" class="form-label">Recargos</label>
                                <input type="number" step="0.1" class="form-control @error('recargos') is-invalid @enderror" name="recargos" value="{{ $modoEdicion ? $pago->recargos : '' }}">
                                @error('recargos')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                        <div class="row">
                            <div class="col-md-4 mb-3">
                                <label for="rezago" class="form-label">Rezagos</label>
                                <input type="number" step="0.1" class="form-control @error('rezago') is-invalid @enderror" name="rezago" value="{{ $modoEdicion ? $pago->rezago : '' }}">
                                @error('rezago')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="multas" class="form-label">Multas</label>
                                <input type="number" step="0.1" class="form-control @error('multas') is-invalid @enderror" name="multas" value="{{ $modoEdicion ? $pago->multas : '' }}">
                                @error('multas')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="gastos_cobranza" class="form-label">Gastos Cobranza</label>
                                <input type="number" step="0.1" class="form-control @error('gastos_cobranza') is-invalid @enderror" name="gastos_cobranza" value="{{ $modoEdicion ? $pago->gastos_cobranza : '' }}">
                                @error('gastos_cobranza')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                        <div class="row">
                            <div class="col-md-4 mb-3">
                                <label for="gastos_envio" class="form-label">Gastos Envio</label>
                                <input type="number" step="0.1" class="form-control @error('gastos_envio') is-invalid @enderror" name="gastos_envio" value="{{ $modoEdicion ? $pago->gastos_envio : '' }}">
                                @error('gastos_envio')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="gastos_notificacion" class="form-label">Gastos Notificación</label>
                                <input type="number" step="0.1" class="form-control @error('gastos_notificacion') is-invalid @enderror" name="gastos_notificacion" value="{{ $modoEdicion ? $pago->gastos_notificacion : '' }}">
                                @error('gastos_notificacion')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                    
                            <div class="col-md-4 mb-3">
                                <label for="descuento" class="form-label">Descuento</label>
                                <input type="descuento" step="0.1" class="form-control @error('descuento') is-invalid @enderror" name="descuento" value="{{ $modoEdicion ? $pago->descuento : '' }}">
                                @error('descuento')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row d-flex justify-content-center ">
                            <div class="col-md-4 mb-3">
                                <label for="fecha_pago" class="form-label">Fecha de Pago</label>
                                <input type="date" class="form-control @error('fecha_pago') is-invalid @enderror" name="fecha_pago" value="{{ $modoEdicion ? $pago->fecha_pago : '' }}">
                                @error('fecha_pago')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    
                       
                    
                        <button type="button" id="enviarDatos" class="btn btn-primary mt-3">Guardar</button>
                    </form>
                    
                    </div>
                </div>
            </div>
        </div>
    @endif

    @push('scripts')
    <script>
       $(document).on('click', '#enviarDatos', function () {
            var datos = {};
            $('#formulario').find('hidden, input, select, textarea').each(function () {
                datos[$(this).attr('name')] = $(this).val();
            });
            console.log(datos);
            Livewire.dispatch('datosRecibidos', { datos: datos });
        });

        // Buscador
        $('#searchInput').on('input', function() {
            @this.set('search', $(this).val()); // Actualiza el valor de la búsqueda
        });

        let selectedStates = [];
        $('#estadosSelect input[type="checkbox"]').on('change', function() {
            selectedStates = [];

            // Obtenemos los valores de los checkboxes seleccionados
            $('#estadosSelect input[type="checkbox"]:checked').each(function() {
                selectedStates.push($(this).val());
            });

            // Enviamos los estados seleccionados a Livewire
            @this.set('estados', selectedStates); // Actualiza la propiedad de Livewire
        });

        // $('#estadosSelect').on('change', function() {
        //     @this.set('estados', $(this).val()); // Actualiza el valor de los estados
        // });

        // Paginación
        $('#paginationSelect').on('change', function() {
            @this.set('perPage', $(this).val()); // Cambia el número de registros por página
        });

       
    </script>

    @endpush

</div>
